@@ -15,6 +15,8 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
+#include <QPrinter>
+#include <QMenu>
 #include "CResources.h"
 #include "CCanvas.h"
 #include "CMapNoMap.h"
@@ -33,6 +35,7 @@
 #include "CMouseAddText.h"
 #include "CMouseAddTextBox.h"
 #include "CMouseAddDistance.h"
+#include "CMouseAddArea.h"
 #include "CMouseOverlay.h"
 #include "CMouseColorPicker.h"
 #include "CMouseSelWpt.h"
@@ -62,7 +65,9 @@
 #include <QtGui>
 
 #include <stdio.h>
+#ifndef QK_QT5_TZONE
 #include <tzdata.h>
+#endif
 
 QPen CCanvas::penBorderBlue(QColor(10,10,150,220),2);
 QPen CCanvas::penBorderBlack(QColor(0,0,0,200),2);
@@ -95,6 +100,7 @@ CCanvas::CCanvas(QWidget * parent)
     mouseAddText    = new CMouseAddText(this);
     mouseAddTextBox = new CMouseAddTextBox(this);
     mouseAddDistance= new CMouseAddDistance(this);
+    mouseAddArea    = new CMouseAddArea(this);
     mouseOverlay    = new CMouseOverlay(this);
     mouseColorPicker = new CMouseColorPicker(this);
     mouseSelWpt     = new CMouseSelWpt(this);
@@ -135,6 +141,7 @@ QColor CCanvas::getSelectedColor()
     return mouseColorPicker->getSelectedColor();
 }
 
+
 void CCanvas::slotMapChanged()
 {
     if(mouse)
@@ -144,6 +151,7 @@ void CCanvas::slotMapChanged()
     update();
 }
 
+
 void CCanvas::slotCopyPosition()
 {
     IMap& map = CMapDB::self().getMap();
@@ -220,6 +228,10 @@ void CCanvas::setMouseMode(mouse_mode_e mode)
             mouse = mouseAddDistance;
             break;
 
+        case eMouseAddArea:
+            mouse = mouseAddArea;
+            break;
+
         case eMouseOverlay:
             mouse = mouseOverlay;
             break;
@@ -354,6 +366,18 @@ void CCanvas::leaveEvent(QEvent * )
 
 #define BORDER  0
 
+
+
+void CCanvas::print(QPrinter& printer)
+{
+    QPainter p;
+
+    p.begin(&printer);
+    print(p, printer.pageRect().size());
+    p.end();
+
+}
+
 void CCanvas::print(QPainter& p, const QSize& pagesize)
 {
     QSize _size_ = pagesize;
@@ -383,15 +407,7 @@ void CCanvas::print(QPainter& p, const QSize& pagesize)
 }
 
 
-void CCanvas::print(QPrinter& printer)
-{
-    QPainter p;
 
-    p.begin(&printer);
-    print(p, printer.pageRect().size());
-    p.end();
-
-}
 
 
 void CCanvas::print(QImage& img)
@@ -438,9 +454,9 @@ void CCanvas::print(QImage& img, const QSize& pagesize)
 #ifdef DEBUG_DRAW
 
 #define DEBUG_TIME(label)\
-    qDebug() << label << et.restart() << "ms";
+qDebug() << label << et.restart() << "ms";
 #else
-    #define DEBUG_TIME(label)
+#define DEBUG_TIME(label)
 #endif
 
 void CCanvas::draw(QPainter& p)
@@ -663,14 +679,20 @@ void CCanvas::drawCompass(QPainter& p)
     p.restore();
 }
 
+
 void CCanvas::drawClock(QPainter& p)
 {
     if(!CResources::self().showClock())
     {
         return;
     }
+#ifdef QK_QT5_TZONE
+    QDateTime tstamp = QDateTime::currentDateTimeUtc().toTimeZone(QTimeZone(timezone.toLatin1()));
+    QString strDateTime = tstamp.toString() + " (" + timezone + ")";;
+#else
     TimeStamp tstamp = TimeStamp::now().toUTC();
     QString strDateTime = tstamp.toZone(timezone).toDateTime().toString() + " (" + timezone + ")";
+#endif
 #ifdef WIN32
     strDateTime = " "+strDateTime+" ";
 #endif
@@ -685,6 +707,7 @@ void CCanvas::drawClock(QPainter& p)
 
 }
 
+
 void CCanvas::drawText(const QString& str, QPainter& p, const QPoint& center, const QColor& color)
 {
     CCanvas::drawText(str,p,center, color, CResources::self().getMapFont());
@@ -860,7 +883,6 @@ void CCanvas::mouseMoveEventCoord(QMouseEvent * e)
     {
         timezone = GPS_Timezone(x*RAD_TO_DEG, y*RAD_TO_DEG);
 
-
         float ele = CMapDB::self().getDEM().getElevation(x,y);
         if(ele != WPT_NOFLOAT)
         {
@@ -1016,6 +1038,7 @@ void CCanvas::slotTime()
     }
 }
 
+
 void CCanvas::setFadingMessage(const QString& msg)
 {
     fadingMessage = msg;
@@ -1031,6 +1054,7 @@ void CCanvas::slotFadingMessage()
 
 }
 
+
 void CCanvas::drawFadingMessage(QPainter& p)
 {
     if(fadingMessage.isEmpty())
@@ -1060,6 +1084,7 @@ void CCanvas::drawFadingMessage(QPainter& p)
     p.drawText(r1, Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap,fadingMessage);
 }
 
+
 void CCanvas::drawTrackLegend(QPainter& p)
 {
     CTrack * track = CTrackDB::self().highlightedTrack();
