@@ -30,11 +30,20 @@
 
 #include <QtGui>
 #include <QtXml>
+#include <QMessageBox>
+#include <QFileDialog>
+#include <qdevicewatcher.h>
 
 CDeviceGarminBulk::CDeviceGarminBulk(QObject * parent)
 : IDevice("Garmin Mass Storage", parent)
 {
+    deviceWatcher = new QDeviceWatcher(this);
+    connect(deviceWatcher, SIGNAL(deviceAdded(QString)), SLOT(slotDevice(QString)));
+    connect(deviceWatcher, SIGNAL(deviceChanged(QString)), SLOT(slotDevice(QString)));
+    connect(deviceWatcher, SIGNAL(deviceRemoved(QString)), SLOT(slotDevice(QString)));
+    deviceWatcher->start();
 
+    qDebug() << "***************************************CDeviceGarminBulk";
 }
 
 
@@ -43,6 +52,10 @@ CDeviceGarminBulk::~CDeviceGarminBulk()
 
 }
 
+void CDeviceGarminBulk::slotDevice(const QString& dev)
+{
+        qDebug() << "!!!!!!!!!!!!!!!!" << dev << "!!!!!!!!!!!!!!!!!!!!!!!!!";
+}
 
 void CDeviceGarminBulk::readDeviceXml(const QString& filename)
 {
