@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -27,18 +27,22 @@
 #include "CDlgDeviceExportPath.h"
 
 #include <QtGui>
+#include <QMessageBox>
+#include <QFileDialog>
 
 CDeviceMagellan::CDeviceMagellan(QObject * parent)
-    : IDevice("Magellan", parent)
+: IDevice("Magellan", parent)
 {
 
 }
 
+
 CDeviceMagellan::~CDeviceMagellan()
 {
 
 }
 
+
 QString CDeviceMagellan::createDayPrefix(QDir& root, const QString& what)
 {
 
@@ -49,6 +53,7 @@ QString CDeviceMagellan::createDayPrefix(QDir& root, const QString& what)
     return prefix;
 }
 
+
 bool CDeviceMagellan::aquire(QDir& dir)
 {
     SETTINGS;
@@ -88,7 +93,6 @@ bool CDeviceMagellan::aquire(QDir& dir)
     pathRts  = dir.absoluteFilePath("Routes");
     pathGC   = dir.absoluteFilePath("Geocaches");
 
-
     cfg.setValue("device/path", pathRoot);
     return true;
 }
@@ -96,7 +100,7 @@ bool CDeviceMagellan::aquire(QDir& dir)
 
 void CDeviceMagellan::uploadWpts(const QList<CWpt*>& wpts)
 {
-//    QMessageBox::information(0,tr("Error..."), tr("Magellan: Upload wapoints is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
+    //    QMessageBox::information(0,tr("Error..."), tr("Magellan: Upload wapoints is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
 
     QDir dir;
     if(!aquire(dir))
@@ -122,7 +126,8 @@ void CDeviceMagellan::uploadWpts(const QList<CWpt*>& wpts)
     }
 
     dir.cd(pathWpt);
-    if(!keysWpt.isEmpty()){
+    if(!keysWpt.isEmpty())
+    {
         CGpx gpx(this, CGpx::eMagellan);
         CWptDB::self().saveGPX(gpx, keysWpt);
         try
@@ -136,7 +141,8 @@ void CDeviceMagellan::uploadWpts(const QList<CWpt*>& wpts)
     }
 
     dir.cd(pathGC);
-    if(!keysGc.isEmpty()){
+    if(!keysGc.isEmpty())
+    {
         CGpx gpx(this, CGpx::eMagellan);
         CWptDB::self().saveGPX(gpx, keysGc);
         try
@@ -152,6 +158,7 @@ void CDeviceMagellan::uploadWpts(const QList<CWpt*>& wpts)
 
 }
 
+
 void CDeviceMagellan::downloadWpts(QList<CWpt*>& wpts)
 {
     //QMessageBox::information(0,tr("Error..."), tr("Magellan: Download wapoints is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
@@ -181,7 +188,6 @@ void CDeviceMagellan::downloadWpts(QList<CWpt*>& wpts)
         CWptDB::self().loadGPX(gpx);
     }
 
-
     dir.cd(pathGC);
 
     files = dir.entryList(QStringList("*gpx"));
@@ -203,9 +209,10 @@ void CDeviceMagellan::downloadWpts(QList<CWpt*>& wpts)
     theMainWindow->getCanvas()->setFadingMessage(tr("Download waypoints finished!"));
 }
 
+
 void CDeviceMagellan::uploadTracks(const QList<CTrack*>& trks)
 {
-//    QMessageBox::information(0,tr("Error..."), tr("Magellan: Upload tracks is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
+    //    QMessageBox::information(0,tr("Error..."), tr("Magellan: Upload tracks is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
 
     QDir dir;
     if(!aquire(dir))
@@ -226,7 +233,7 @@ void CDeviceMagellan::uploadTracks(const QList<CTrack*>& trks)
         try
         {
             QCryptographicHash md5(QCryptographicHash::Md5);
-            md5.addData(trk->getKey().toAscii());
+            md5.addData(trk->getKey().toLatin1());
             QString hash = md5.result().toHex();
 
             gpx.save(dir.absoluteFilePath(QString("%1_%2.gpx").arg(prefix).arg(hash)));
@@ -238,13 +245,13 @@ void CDeviceMagellan::uploadTracks(const QList<CTrack*>& trks)
 
     }
 
-
     theMainWindow->getCanvas()->setFadingMessage(tr("Upload tracks finished!"));
 }
 
+
 void CDeviceMagellan::downloadTracks(QList<CTrack*>& trks)
 {
-//    QMessageBox::information(0,tr("Error..."), tr("Magellan: Download tracks is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
+    //    QMessageBox::information(0,tr("Error..."), tr("Magellan: Download tracks is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
     QStringList files;
     QDir dir;
     if(!aquire(dir))
@@ -273,26 +280,31 @@ void CDeviceMagellan::downloadTracks(QList<CTrack*>& trks)
     theMainWindow->getCanvas()->setFadingMessage(tr("Download tracks finished!"));
 }
 
+
 void CDeviceMagellan::uploadRoutes(const QList<CRoute*>& rtes)
 {
     QMessageBox::information(0,tr("Error..."), tr("Magellan: Upload routes is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
 }
 
+
 void CDeviceMagellan::downloadRoutes(QList<CRoute*>& rtes)
 {
     QMessageBox::information(0,tr("Error..."), tr("Magellan: Download routes is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
 }
 
+
 void CDeviceMagellan::uploadMap(const QList<IMapSelection*>& mss)
 {
     QMessageBox::information(0,tr("Error..."), tr("Magellan: Upload maps is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
 }
 
+
 void CDeviceMagellan::setLiveLog(bool on)
 {
     QMessageBox::information(0,tr("Error..."), tr("Magellan: Live log is not supported."),QMessageBox::Abort,QMessageBox::Abort);
 }
 
+
 void CDeviceMagellan::downloadScreenshot(QImage& image)
 {
     QMessageBox::information(0,tr("Error..."), tr("Magellan: Screen shot is not supported."),QMessageBox::Abort,QMessageBox::Abort);
