@@ -28,6 +28,9 @@
 
 #include <QtGui>
 #include <QNetworkProxy>
+#include <QColorDialog>
+#include <QFileDialog>
+#include <QFontDialog>
 
 #define XSTR(x) STR(x)
 #define STR(x) #x
@@ -35,7 +38,7 @@
 CDlgConfig::CDlgConfig(QWidget * parent)
 : QDialog(parent)
 {
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
     this->setParent(qApp->focusWidget());
     this->setWindowModality(Qt::WindowModal);
     this->setWindowFlags(Qt::Sheet);
@@ -67,7 +70,11 @@ CDlgConfig::~CDlgConfig()
 }
 
 
+#ifdef QK_QT5_PORT
+int CDlgConfig::exec()
+#else
 void CDlgConfig::exec()
+#endif
 {
     CResources& resources = CResources::self();
 
@@ -124,7 +131,7 @@ void CDlgConfig::exec()
     comboDevice->addItem(tr("TwoNav"), "TwoNav");
     comboDevice->addItem(tr("NMEA"), "NMEA");
 
-	checkWatchDog->setChecked(resources.m_watchdogEnabled);
+    checkWatchDog->setChecked(resources.m_watchdogEnabled);
 
     comboDevBaudRate->addItem("4800");
     comboDevBaudRate->addItem("9600");
@@ -133,9 +140,6 @@ void CDlgConfig::exec()
     comboDevBaudRate->addItem("57600");
     comboDevBaudRate->addItem("115200");
     comboDevBaudRate->setCurrentIndex(comboDevBaudRate->findText(resources.m_devBaudRate));
-#ifdef HS_MIKROKOPTER
-    comboDevice->addItem(tr("Mikrokopter"), "Mikrokopter");
-#endif
 #ifdef HAS_GPSD
     comboDevice->addItem(tr("GPSD"), "GPSD");
 #endif
@@ -149,7 +153,7 @@ void CDlgConfig::exec()
     lineDevIPPort->setText(QString::number(resources.m_devIPPort));
     lineDevSerialPort->setText(resources.m_devSerialPort);
 #ifdef Q_OS_WIN32
-    lineDevSerialPort->setToolTip(tr("Pass something like \"COM1:\" or \"\\\\.\\COM13\" or \"\\\\.\\com13\" for serial Garmin devices or NMEA devices. For Garmin USB devices leave blank."));
+    lineDevSerialPort->setToolTip(tr("Pass something like \"COM1\" or \"\\\\.\\COM13\" or \"\\\\.\\com13\" for serial Garmin devices or NMEA devices. For Garmin USB devices leave blank."));
 #endif
 
     checkDownloadTrk->setChecked(IDevice::m_DownloadAllTrk);
@@ -185,7 +189,11 @@ void CDlgConfig::exec()
         radioTimeZone->setChecked(true);
     }
 
+#ifdef QK_QT5_PORT
+    return QDialog::exec();
+#else
     QDialog::exec();
+#endif
 }
 
 
@@ -248,7 +256,7 @@ void CDlgConfig::accept()
     resources.m_devIPPort       = lineDevIPPort->text().toUShort();
     resources.m_devSerialPort   = lineDevSerialPort->text();
     resources.m_devBaudRate     = comboDevBaudRate->currentText();
-	resources.m_watchdogEnabled = checkWatchDog->isChecked();
+    resources.m_watchdogEnabled = checkWatchDog->isChecked();
     resources.m_devType         = comboDevType->itemText(comboDevType->currentIndex());
     resources.m_devCharset      = comboDevCharset->itemText(comboDevCharset->currentIndex());
 
@@ -366,7 +374,7 @@ void CDlgConfig::fillTypeCombo()
     QRegExp regex("lib(.*)\\" XSTR(SHARED_LIB_EXT));
     QString file;
     QStringList files;
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
     // MacOS X: plug-ins are stored in the bundle folder
     QDir inst_dir(QCoreApplication::applicationDirPath()
         .replace(QRegExp("MacOS$"), "Resources/Drivers"));
@@ -386,7 +394,7 @@ void CDlgConfig::fillTypeCombo()
 
     if(files.isEmpty())
     {
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
         labelMessage->setText(tr("No plugins found. I expect them in: %1")
             .arg(QCoreApplication::applicationDirPath()
             .replace(QRegExp("MacOS$"), "Resources/Drivers")));
