@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -30,7 +30,11 @@ class CDlgConfig : public QDialog, private Ui::IDlgConfig
         virtual ~CDlgConfig();
 
     public slots:
+#ifdef QK_QT5_PORT
+        int exec();
+#else
         void exec();
+#endif
         void accept();
 
     private slots:
