@@ -16,6 +16,15 @@
 
 **********************************************************************************************/
 
+#include <QMenu>
+#include <QSplitter>
+#include <QMessageBox>
+#include <QPrinter>
+#include <QPrintDialog>
+#include <QFileDialog>
+#include <QStatusBar>
+#include <QMenuBar>
+#include <QDesktopWidget>
 #include "CMainWindow.h"
 #include "CMegaMenu.h"
 #include "CCanvas.h"
@@ -96,12 +105,6 @@ CMainWindow::CMainWindow()
     canvasTab = new CTabWidget(this);
     rightSplitter->addWidget(canvasTab);
 
-#ifdef DO_PROFILING
-    Q_INIT_RESOURCE(Conan);
-    conanWidget = new conan::ConanWidget(this);
-    canvasTab->addTab(conanWidget,tr("Profiling"));
-#endif
-
     canvas = new CCanvas(this);
     canvasTab->addTab(canvas,tr("Map"));
 
@@ -147,18 +150,14 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::MapMenu, "aSelectArea");
     actionGroupProvider->addAction(CMenus::MapMenu, "aEditMap");
     actionGroupProvider->addAction(CMenus::MapMenu, "aSearchMap");
-#ifdef PLOT_3D
     actionGroupProvider->addAction(CMenus::MapMenu, "aSwitchToMap3D");
-#endif
     actionGroupProvider->addAction(CMenus::MapMenu, "aUploadMap");
 
-#ifdef PLOT_3D
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aCloseMap3D");
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DMode");
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DFPVMode");
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DLighting");
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DTrackMode");
-#endif
 
     actionGroupProvider->addAction(CMenus::WptMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::WptMenu, "aMoveArea");
@@ -198,6 +197,7 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aText");
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aTextBox");
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aSwitchToOverlayDistance");
+    actionGroupProvider->addAction(CMenus::OverlayMenu, "aSwitchToOverlayArea");
 
     actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aBackToOverlay");
     actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aMoveArea");
@@ -206,6 +206,12 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aCombineDistOvl");
     actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aDistance");
 
+    actionGroupProvider->addAction(CMenus::OverlayAreaMenu, "aBackToOverlay");
+    actionGroupProvider->addAction(CMenus::OverlayAreaMenu, "aMoveArea");
+    actionGroupProvider->addAction(CMenus::OverlayAreaMenu, "aZoomArea");
+    actionGroupProvider->addAction(CMenus::OverlayAreaMenu, "aCenterMap");
+    actionGroupProvider->addAction(CMenus::OverlayAreaMenu, "aArea");
+
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aZoomArea");
@@ -275,9 +281,6 @@ CMainWindow::CMainWindow()
     diarydb     = new CDiaryDB(canvasTab, this);
     searchdb    = new CSearchDB(tabbar, this);
 
-#ifdef DO_PROFILING
-    conanWidget->AddRootObject(this);
-#endif
 
     if(resources->useGeoDB())
     {
@@ -585,7 +588,7 @@ void CMainWindow::setupMenuBar()
     //menu->addAction(QIcon(":/icons/iconPrint16x16.png"),tr("Print Diary ..."),this,SLOT(slotPrintPreview()));
     menu->addSeparator();
     menu->addAction(QIcon(":/icons/iconUnknown16x16.png"),tr("Toggle toolview"),this,SLOT(slotToggleToolView()), Qt::CTRL + Qt::Key_T);
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
     menu->addAction(QIcon(":/icons/iconExit16x16.png"),("Exit"),this,SLOT(close()), Qt::CTRL + Qt::Key_Q);
 #else
     menu->addAction(QIcon(":/icons/iconExit16x16.png"),tr("Exit"),this,SLOT(close()), Qt::CTRL + Qt::Key_Q);
@@ -637,7 +640,7 @@ void CMainWindow::setupMenuBar()
 
     menu = new QMenu(this);
     menu->setTitle(tr("&Setup"));
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
     menu->addAction(QIcon(":/icons/iconConfig16x16.png"),"&Preferences",this,SLOT(slotConfig()));
 #else
     menu->addAction(QIcon(":/icons/iconConfig16x16.png"),tr("&General"),this,SLOT(slotConfig()));
@@ -645,7 +648,7 @@ void CMainWindow::setupMenuBar()
     menuBar()->addMenu(menu);
 
     menu = new QMenu(this);
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
     menu->setTitle(("&Help"));
     menu->addAction(QIcon(":/icons/iconHelp16x16.png"),("http://FAQ"),this,SLOT(slotFAQ()));
     menu->addAction(QIcon(":/icons/iconHelp16x16.png"),("http://Help"),this,SLOT(slotHelp()));
@@ -698,11 +701,7 @@ void CMainWindow::slotLoadMapSet()
     QString filter   = cfg.value("maps/filter","").toString();
     QString filename = QFileDialog::getOpenFileName( 0, tr("Select map...")
         ,CResources::self().pathMaps
-    #ifdef HAS_RMAP
         ,"All (*.*);;Map Collection (*.qmap);;Garmin (*.tdb);;BirdsEye (*.jnx);;TwoNav (*.rmap);;Magellan (*.rmp)"
-    #else
-        ,"All (*.*);;Map Collection (*.qmap);;Garmin (*.tdb);;BirdsEye (*.jnx);;Magellan (*.rmp)"
-    #endif
         , &filter
         , FILE_DIALOG_FLAGS
         );
@@ -894,32 +893,32 @@ bool CMainWindow::loadData(const QString& filename, const QString& filter)
 
             if(filter.startsWith("TwoNav"))
             {
-                loadGPXData = convertData("compegps", filename, "gpx", tmpfile.fileName());
+                loadGPXData = convertData("compegps", filename, "gpx,garminextensions", tmpfile.fileName());
             }
             else if(ext == "LOC")
             {
-                loadGPXData = convertData("geo", filename, "gpx", tmpfile.fileName());
+                loadGPXData = convertData("geo", filename, "gpx,garminextensions", tmpfile.fileName());
             }
             else if(ext == "GDB")
             {
 
-                loadGPXData = convertData("gdb", filename, "gpx", tmpfile.fileName());
+                loadGPXData = convertData("gdb", filename, "gpx,garminextensions", tmpfile.fileName());
             }
             else if(ext == "KML")
             {
-                loadGPXData = convertData("kml", filename, "gpx", tmpfile.fileName());
+                loadGPXData = convertData("kml", filename, "gpx,garminextensions", tmpfile.fileName());
             }
             else if(ext == "PLT" || ext == "WPT" || ext == "RTE")
             {
-                loadGPXData = convertData("ozi", filename, "gpx", tmpfile.fileName());
+                loadGPXData = convertData("ozi", filename, "gpx,garminextensions", tmpfile.fileName());
             }
             else if(ext == "TK1")
             {
-                loadGPXData = convertData("wbt-tk1", filename, "gpx", tmpfile.fileName());
+                loadGPXData = convertData("wbt-tk1", filename, "gpx,garminextensions", tmpfile.fileName());
             }
             else if(ext =="CSV")
             {
-                loadGPXData = convertData("unicsv", filename, "gpx", tmpfile.fileName());
+                loadGPXData = convertData("unicsv", filename, "gpx,garminextensions", tmpfile.fileName());
             }
 
             if (!loadGPXData)
@@ -1281,7 +1280,6 @@ void CMainWindow::slotSaveImage()
         filename += ".png";
     }
 
-#ifdef PLOT_3D
     CMap3D * map3d = qobject_cast<CMap3D*>(canvasTab->currentWidget());
 
     if(map3d)
@@ -1289,7 +1287,6 @@ void CMainWindow::slotSaveImage()
         map3d->slotSaveImage(filename);
     }
     else
-#endif
     {
         QImage img(canvas->size(), QImage::Format_ARGB32);
         canvas->print(img);
@@ -1436,9 +1433,6 @@ void CMainWindow::slotDeviceChanged()
     comboDevice->addItem(tr("Magellan"), "Magellan");
     comboDevice->addItem(tr("TwoNav"), "TwoNav");
     comboDevice->addItem(tr("NMEA"), "NMEA");
-#ifdef HS_MIKROKOPTER
-    comboDevice->addItem(tr("Mikrokopter"), "Mikrokopter");
-#endif
 #ifdef HAS_GPSD
     comboDevice->addItem(tr("GPSD"), "GPSD");
 #endif
@@ -1575,17 +1569,17 @@ void CMainWindow::slotUpdate()
     if(result == -1)
     {
         QString msg = tr(
-                "QLandkarte GT can query for new versions on start-up. If there is a new version available, it will display a short notice in the statusbar. "
-                "To query for a new version QLandkarte GT has to connect to the server"
-                "\n\n"
-                "http://www.qlandkarte.org/webservice/qlandkartegt.php"
-                "\n\n"
-                "It won't transmit any private data other than needed for requesting a HTML page."
-                "\n\n"
-                "If you want QLandkarte GT to do this query now and in the future press 'Ok'. Else press 'No'."
-                "\n\n"
-                "You won't be bugged a second time unless you erase QLandkarte's configuration data."
-                    );
+            "QLandkarte GT can query for new versions on start-up. If there is a new version available, it will display a short notice in the statusbar. "
+            "To query for a new version QLandkarte GT has to connect to the server"
+            "\n\n"
+            "http://www.qlandkarte.org/webservice/qlandkartegt.php"
+            "\n\n"
+            "It won't transmit any private data other than needed for requesting a HTML page."
+            "\n\n"
+            "If you want QLandkarte GT to do this query now and in the future press 'Ok'. Else press 'No'."
+            "\n\n"
+            "You won't be bugged a second time unless you erase QLandkarte's configuration data."
+            );
 
         QMessageBox::StandardButton r = QMessageBox::question(this, tr("Query for new version..."),msg,QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok);
         if(r == QMessageBox::Ok)
