@@ -27,6 +27,9 @@
 #include "CSettings.h"
 
 #include <QtGui>
+#include <QMenu>
+#include <QMessageBox>
+#include <QFileDialog>
 
 CPlot::CPlot(CPlotData::axis_type_e type, mode_e mode, QWidget * parent)
 : QWidget(parent)
@@ -136,12 +139,13 @@ void CPlot::setLimits()
     m_pData->setLimits();
 }
 
+
 void CPlot::newLine(const QPolygonF& line, const QList<QPointF>& focus, const QString& label)
 {
     m_pData->lines.clear();
 
     QRectF r = line.boundingRect();
-    if(!r.height() < 0 || r.width() < 0)
+    if((r.height() < 0) || (r.width() < 0))
     {
         m_pData->badData = true;
         return;
@@ -484,7 +488,6 @@ void CPlot::draw(QPainter& p)
                 p.drawText(r1, Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap,str);
             }
 
-
             x   = posMouse.x();
             str = track->getTrkPtInfo2(*selTrkPt);
             if(!str.isEmpty() && m_pData->focus.isEmpty())
@@ -693,7 +696,6 @@ void CPlot::drawYScale( QPainter &p )
         t = m_pData->y().ticmark( t );
     }
 
-
     if((limMax - limMin) <= (useMax - useMin)) return;
 
     double scale = (top - bottom) / (limMax - limMin);
@@ -807,7 +809,6 @@ void CPlot::drawGridY( QPainter &p )
         p.drawLine( ix, iy, ix + dx, iy );
     }
 
-
     p.setPen( oldpen );
     m_pData->y().setTicType( oldtic );
 }
@@ -937,7 +938,6 @@ void CPlot::drawData(QPainter& p)
         p.drawPolyline(background.mid(1,line.size()));
         p.restore();
 
-
     }
 
     if(m_pData->focus.size() < 2)
@@ -987,7 +987,6 @@ void CPlot::drawData(QPainter& p)
                     pty = pty - r1.height();
                 }
 
-
                 r1.moveTopLeft(QPoint(ptx, pty));
 
                 QRect r2 = r1;
