@@ -28,32 +28,38 @@
 #include "CSettings.h"
 
 #include <QtGui>
-#include <QtNetwork/QHttp>
-#include <QtNetwork/QNetworkProxy>
+#include <QNetworkProxy>
+#include <QMessageBox>
+#include <QProgressDialog>
 
+#ifndef QK_QT5_TZONE
 #include <tzdata.h>
+#endif
 
 #ifndef _MKSTR_1
 #define _MKSTR_1(x)    #x
 #define _MKSTR(x)      _MKSTR_1(x)
 #endif
 
+#define ASCEND_THRESHOLD    5
+
 QDir CTrack::path(_MKSTR(MAPPATH) "/Track");
 
 QVector<CTrack::multi_color_setup_t> CTrack::setupMultiColor;
 
 CTrack::multi_color_setup_t::multi_color_setup_t(multi_color_setup_e modeMinMax, float min, float max, int minH, int maxH, const QString &name)
-    : modeMinMax(modeMinMax)
-    , minVal(min)
-    , markVal(WPT_NOFLOAT)
-    , maxVal(max)
-    , minHue(minH)
-    , maxHue(maxH)
-    , name(name)
+: modeMinMax(modeMinMax)
+, minVal(min)
+, markVal(WPT_NOFLOAT)
+, maxVal(max)
+, minHue(minH)
+, maxHue(maxH)
+, name(name)
 {
     buildColorTable();
 }
 
+
 void CTrack::multi_color_setup_t::buildColorTable()
 {
     if(minHue > maxHue)
@@ -75,6 +81,7 @@ void CTrack::multi_color_setup_t::buildColorTable()
 
 }
 
+
 void CTrack::multi_color_setup_t::save(QSettings& cfg)
 {
     cfg.beginGroup(name);
@@ -88,6 +95,7 @@ void CTrack::multi_color_setup_t::save(QSettings& cfg)
     cfg.endGroup();
 }
 
+
 void CTrack::multi_color_setup_t::restore(QSettings& cfg)
 {
     cfg.beginGroup(name);
@@ -474,7 +482,6 @@ QDataStream& operator <<(QDataStream& s, CTrack& track)
 
     entries << entryTrkPts2;
 
-
     //---------------------------------------
     // prepare trainings data
     //---------------------------------------
@@ -799,6 +806,7 @@ CTrack::~CTrack()
 
 }
 
+
 void CTrack::getMultiColor(bool& on, int& id, QList<multi_color_item_t>& items)
 {
     items << multi_color_item_t(tr("solid"), eMultiColorNone);
@@ -810,19 +818,22 @@ void CTrack::getMultiColor(bool& on, int& id, QList<multi_color_item_t>& items)
     id = idMultiColor;
 }
 
+
 CTrack::multi_color_setup_t& CTrack::getMultiColorSetup(int id)
 {
     return setupMultiColor[id];
 }
 
+
 void CTrack::setMultiColor(bool on, int id)
 {
-     useMultiColor = on;
-     idMultiColor  = id;
+    useMultiColor = on;
+    idMultiColor  = id;
 
-     rebuild(false);
+    rebuild(false);
 }
 
+
 #include "CPlotAxis.h"
 void CTrack::drawMultiColorLegend(QPainter& p)
 {
@@ -916,7 +927,6 @@ void CTrack::drawMultiColorLegend(QPainter& p)
         recTextMax = recText;
     }
 
-
     // tic marks and other labels
     while ( t )
     {
@@ -944,6 +954,7 @@ void CTrack::drawMultiColorLegend(QPainter& p)
 
 }
 
+
 void CTrack::setHighlight(bool yes)
 {
     highlight = yes;
@@ -1001,12 +1012,20 @@ void CTrack::replaceElevationByRemote(bool replaceOrignalData)
 
         QUrl url("http://ws.geonames.org");
         url.setPath("/srtm3");
+#ifdef QK_QT5_PORT
+        QUrlQuery urlQuery;
+        urlQuery.addQueryItem("lats",lats.join(","));
+        urlQuery.addQueryItem("lngs",lngs.join(","));
+        urlQuery.addQueryItem("username",username);
+        url.setQuery(urlQuery);
+#else
         url.addQueryItem("lats",lats.join(","));
         url.addQueryItem("lngs",lngs.join(","));
         url.addQueryItem("username",username);
+#endif
 
         QNetworkRequest request;
-        
+
         request.setUrl(url);
         QNetworkReply * reply = networkAccessManager->get(request);
 
@@ -1078,7 +1097,6 @@ void CTrack::slotRequestFinished(QNetworkReply * reply)
 }
 
 
-
 QRectF CTrack::getBoundingRectF()
 {
 
@@ -1203,6 +1221,7 @@ void CTrack::rebuild(bool reindex)
     float minEle    =  WPT_NOFLOAT;
     float maxSpeed  = -WPT_NOFLOAT;
     float minSpeed  =  WPT_NOFLOAT;
+    float lastEle   = 0;
 
     // reindex track if desired
     if(reindex)
@@ -1248,6 +1267,7 @@ void CTrack::rebuild(bool reindex)
     pt1->slope2     = 0.0;
     t1              = pt1->timestamp;
     t2              = t1;        //for the case that the track has only 1 point
+    lastEle         = pt1->ele;
 
     pt1Slope = pt1;
 
@@ -1255,8 +1275,8 @@ void CTrack::rebuild(bool reindex)
 
     if(pt1->ele   > maxEle)   {maxEle   = pt1->ele;   ptMaxEle   = *pt1;}
     if(pt1->ele   < minEle)   {minEle   = pt1->ele;   ptMinEle   = *pt1;}
-//    if(pt1->speed > maxSpeed) {maxSpeed = pt1->speed; ptMaxSpeed = *pt1;}
-//    if(pt1->speed < minSpeed) {minSpeed = pt1->speed; ptMinSpeed = *pt1;}
+    //    if(pt1->speed > maxSpeed) {maxSpeed = pt1->speed; ptMaxSpeed = *pt1;}
+    //    if(pt1->speed < minSpeed) {minSpeed = pt1->speed; ptMinSpeed = *pt1;}
 
     // process track
     while(++pt2 != track.end())
@@ -1297,6 +1317,8 @@ void CTrack::rebuild(bool reindex)
 
         pt2->delta      = distance(p1,p2,pt1->azimuth,a2);
         pt2->distance   = pt1->distance + pt2->delta;
+
+        // slope in degree
         if ((pt1->ele != WPT_NOFLOAT) && (pt2->ele != WPT_NOFLOAT))
         {
             slope = pt2->ele - pt1->ele;
@@ -1305,23 +1327,31 @@ void CTrack::rebuild(bool reindex)
         {
             slope = 0.;
         }
-
         pt2->slope    = atan(slope / pt2->delta) * 360 / (2*M_PI);
+
         if (qAbs(pt2->slope )>100)
         {
             pt2->slope = pt1->slope;
         }
 
-        if(slope > 0)
+        // ascend descend
+        qreal d = pt2->ele - lastEle;
+        if(fabs(d) > ASCEND_THRESHOLD)
         {
-            totalAscend  += slope;
-        }
-        else
-        {
-            totalDescend += slope;
+            if(d > 0)
+            {
+                totalAscend += d;
+            }
+            else
+            {
+                totalDescend -= d;
+            }
+            lastEle = pt2->ele;
         }
         pt2->ascend     = totalAscend;
         pt2->descend    = totalDescend;
+
+        // speeds
         if(ext1Data && pt2->velocity != WPT_NOFLOAT)
         {
             pt2->speed  =  pt2->velocity;
@@ -1341,8 +1371,8 @@ void CTrack::rebuild(bool reindex)
 
         if(pt2->ele   > maxEle)   {maxEle   = pt2->ele;   ptMaxEle   = *pt2;}
         if(pt2->ele   < minEle)   {minEle   = pt2->ele;   ptMinEle   = *pt2;}
-//        if(pt2->speed > maxSpeed) {maxSpeed = pt2->speed; ptMaxSpeed = *pt2;}
-//        if(pt2->speed < minSpeed) {minSpeed = pt2->speed; ptMinSpeed = *pt2;}
+        //        if(pt2->speed > maxSpeed) {maxSpeed = pt2->speed; ptMaxSpeed = *pt2;}
+        //        if(pt2->speed < minSpeed) {minSpeed = pt2->speed; ptMinSpeed = *pt2;}
 
         pt2->timeSinceStart = t2 - t1;
 
@@ -1360,7 +1390,6 @@ void CTrack::rebuild(bool reindex)
             }
         }
 
-
         pt1 = pt2;
     }
 
@@ -1436,7 +1465,6 @@ void CTrack::rebuild(bool reindex)
         if(pt.speed < minSpeed) {minSpeed = pt.speed; ptMinSpeed = pt;}
     }
 
-
     rebuildColorMap();
 
     emit sigChanged();
@@ -1465,6 +1493,7 @@ void CTrack::rebuildColorMap()
     }
 }
 
+
 void CTrack::rebuildColorMapElevation()
 {
     multi_color_setup_t& setup = setupMultiColor[eMultiColorEle];
@@ -1498,6 +1527,7 @@ void CTrack::rebuildColorMapElevation()
 
 }
 
+
 void CTrack::rebuildColorMapSpeed()
 {
     multi_color_setup_t& setup = setupMultiColor[eMultiColorSpeed];
@@ -1534,6 +1564,7 @@ void CTrack::rebuildColorMapSpeed()
 
 }
 
+
 void CTrack::rebuildColorMapSlope()
 {
     multi_color_setup_t& setup = setupMultiColor[eMultiColorSlope];
@@ -1567,6 +1598,7 @@ void CTrack::rebuildColorMapSlope()
 
 }
 
+
 void CTrack::rebuildColorMapDefault()
 {
     for(int i = 0; i < track.size(); i++)
@@ -1699,6 +1731,7 @@ void CTrack::setPointOfFocus(int idx, type_select_e typeSelect, bool moveMap)
     emit sigNeedUpdate();
 }
 
+
 void CTrack::getPointOfFocus(QList<CTrack::pt_t>& points)
 {
     foreach(const pt_t& trkpt, track)
@@ -1710,6 +1743,7 @@ void CTrack::getPointOfFocus(QList<CTrack::pt_t>& points)
     }
 }
 
+
 void CTrack::setupIterators(QList<pt_t>::iterator& begin, QList<pt_t>::iterator& end)
 {
     QList<pt_t>& trkpts     = getTrackPoints();
@@ -1760,7 +1794,11 @@ QDateTime CTrack::getStartTimestamp()
         QDateTime time = QDateTime::fromTime_t(trkpt->timestamp);
         if(!timezone.isEmpty())
         {
+#ifdef QK_QT5_PORT
+            time = time.toTimeZone(QTimeZone(timezone.toLatin1()));
+#else
             time = TimeStamp(trkpt->timestamp).toZone(timezone).toDateTime();
+#endif
         }
         return time;
     }
@@ -1782,7 +1820,11 @@ QDateTime CTrack::getEndTimestamp()
         QDateTime time = QDateTime::fromTime_t(trkpt->timestamp);
         if(!timezone.isEmpty())
         {
+#ifdef QK_QT5_TZONE
+            time = time.toTimeZone(QTimeZone(timezone.toLatin1()));
+#else
             time = TimeStamp(trkpt->timestamp).toZone(timezone).toDateTime();
+#endif
         }
         return time;
     }
@@ -1905,7 +1947,11 @@ QString CTrack::getTrkPtInfo1(pt_t& trkpt)
         QDateTime time = QDateTime::fromTime_t(trkpt.timestamp);
         if(!timezone.isEmpty())
         {
+#ifdef QK_QT5_TZONE
+            time = time.toTimeZone(QTimeZone(timezone.toLatin1()));
+#else
             time = TimeStamp(trkpt.timestamp).toZone(timezone).toDateTime();
+#endif
         }
 
         str = time.toString();
@@ -1985,7 +2031,6 @@ QString CTrack::getTrkPtInfo1(pt_t& trkpt)
         str += tr("speed: %1%2").arg(val).arg(unit);
     }
 
-
     if((trkpt.heartReateBpm != -1) || (trkpt.cadenceRpm != -1))
     {
         if(str.count()) str += "\n";
@@ -2024,7 +2069,6 @@ QString CTrack::getTrkPtInfo1(pt_t& trkpt)
 
     }
 
-
     return str;
 }
 
@@ -2104,6 +2148,7 @@ QString CTrack::getTrkPtInfo2(pt_t& trkpt)
     return str;
 }
 
+
 QString CTrack::getFocusInfo()
 {
     double tmp, d;
@@ -2133,16 +2178,15 @@ QString CTrack::getFocusInfo()
     }
     tmp = p2.ascend - p1.ascend;
     IUnit::self().meter2elevation(tmp, val, unit);
-    str += QString("%3 %1%2 (%4\260)\n").arg(val).arg(unit).arg(QChar(0x2197)).arg(qRound(atan(tmp/d) * 360 / (2*M_PI)));
+    str += QString("%3 %1%2 (%4%5)\n").arg(val).arg(unit).arg(QChar(0x2197)).arg(qRound(atan(tmp/d) * 360 / (2*M_PI))).arg(QChar(0260));
     tmp = p1.descend - p2.descend;
     IUnit::self().meter2elevation(tmp, val, unit);
-    str += QString("%3 %1%2 (%4\260)").arg(val).arg(unit).arg(QChar(0x2198)).arg(qRound(atan(tmp/d) * 360 / (2*M_PI)));
-
-
+    str += QString("%3 %1%2 (%4%5)").arg(val).arg(unit).arg(QChar(0x2198)).arg(qRound(atan(tmp/d) * 360 / (2*M_PI))).arg(QChar(0260));
 
     return str;
 }
 
+
 void CTrack::setDoScaleWpt2Track(Qt::CheckState state)
 {
     doScaleWpt2Track = state;
@@ -2258,7 +2302,6 @@ void CTrack::slotScaleWpt2Track()
 
     qSort(waypoints.begin(), waypoints.end(), qSortWptLessDistance);
 
-
     QApplication::restoreOverrideCursor();
     return ;
 }
@@ -2318,6 +2361,7 @@ void CTrack::medianFilter(qint32 len, QProgressDialog& progress)
 
 }
 
+
 void CTrack::offsetElevation(double offset)
 {
 
@@ -2335,6 +2379,7 @@ void CTrack::offsetElevation(double offset)
     }
 }
 
+
 void CTrack::changeStartTime(QDateTime& time)
 {
 
@@ -2354,6 +2399,7 @@ void CTrack::changeStartTime(QDateTime& time)
     }
 }
 
+
 void CTrack::changeSpeed(double speed)
 {
     double deltaD;
@@ -2409,6 +2455,7 @@ void CTrack::changeSpeed(double speed)
     }
 }
 
+
 bool CTrack::unifyTimestamps(quint32 delta)
 {
     QList<CTrack::pt_t>::iterator trkpt, end;
@@ -2448,6 +2495,7 @@ bool CTrack::unifyTimestamps(quint32 delta)
     return true;
 }
 
+
 void CTrack::reset()
 {
     QList<CTrack::pt_t>::iterator trkpt, end;
